@@ -4,16 +4,19 @@ from archetypes.schemaextender.field import ExtensionField
 from Products.Archetypes import atapi
 from Products.Archetypes.utils import OrderedDict
 
+
 class StringExtField(ExtensionField, atapi.StringField):
     """Selection Field for schemaextender
     """
 
+
 class ThemeSelectionExtender(object):
     """Schema extender for Child Site Theme Selection.
     """
 
     fields = [
-        StringExtField('lineage_theme',
+        StringExtField(
+            'lineage_theme',
             schemata='settings',
             mode="w",
             write_permission="Manage portal",
